////////////////////////////////////////////////////////////////////////////////
//     
//    __                                ______
//   / /_______________  ____  ___     / ____/
//  / __/ ___/ ___/ __ \/ __ \/ _ \   /___ )  
// / /_(__  ) /__/ /_/ / /_/ /  __/  ____/ /  
// \__/____/\___/\____/ .___/\___/  /_____/   
//                   /_/                      
//     
/// \file bitmaps.h
/// Declarations of bitmap functions
////////////////////////////////////////////////////////////////////////////////

#pragma once

#include "system.h"


#ifdef __cplusplus
extern "C" {
#endif
	
TS5_BITMAP *ts5_alloc_bitmap(double w, double h);
TS5_BITMAP *ts5_read_bitmap(const char *file);
void ts5_write_bitmap(const char *file, TS5_BITMAP *map);
void ts5_free_bitmap(TS5_BITMAP *map);

void ts5_get_bitmap_size(TS5_BITMAP *map, double *w, double *h);
double ts5_get_bitmap_width(TS5_BITMAP *map);
double ts5_get_bitmap_height(TS5_BITMAP *map);

TS5_BITMAP *ts5_set_drawing_target(TS5_BITMAP *target);
TS5_BITMAP *ts5_get_drawing_target();
void ts5_get_target_size(double *w, double *h);
double ts5_get_target_width();
double ts5_get_target_height();

void ts5_draw_bitmap(TS5_BITMAP *map, double dx, double dy);

void ts5_draw_flipped_bitmap(TS5_BITMAP *map, 
	double dx, double dy, const int flip);

void ts5_draw_tinted_bitmap(TS5_BITMAP *map, 
	TS5_COLOR tint, double dx, double dy);

void ts5_draw_bitmap_region(TS5_BITMAP *map, 
	double sx1, double sy1, double sx2, double sy2, double dx, double dy);

void ts5_draw_rotated_bitmap(TS5_BITMAP *map, 
	double cx, double cy, double angle, double dx, double dy);

void ts5_draw_scaled_bitmap(TS5_BITMAP *map, 
	double xratio, double yratio, double dx, double dy);

#ifdef __cplusplus
}
#endif

