////////////////////////////////////////////////////////////////////////////////
//     
//    __                                ______
//   / /_______________  ____  ___     / ____/
//  / __/ ___/ ___/ __ \/ __ \/ _ \   /___ )  
// / /_(__  ) /__/ /_/ / /_/ /  __/  ____/ /  
// \__/____/\___/\____/ .___/\___/  /_____/   
//                   /_/                      
//     
/// \file graphics.h
/// Declarations of graphics parameter functions
////////////////////////////////////////////////////////////////////////////////

#pragma once

#include "system.h"


#ifdef __cplusplus
extern "C" {
#endif
	
int ts5_set_coordinate_system(const int coordinate_system);
int ts5_get_coordinate_system();
int ts5_set_coordinate_scale(const int coordinate_scale);
int ts5_get_coordinate_scale();


#define ax(x) ts5_relative_to_absolute_coordinate_x(x)
#define ay(y) ts5_relative_to_absolute_coordinate_y(y)
double ts5_relative_to_absolute_coordinate_x(const double x);
double ts5_relative_to_absolute_coordinate_y(const double y);

#define rx(x) ts5_absolute_to_relative_coordinate_x(x)
#define ry(y) ts5_absolute_to_relative_coordinate_y(y)
double ts5_absolute_to_relative_coordinate_x(const double x);
double ts5_absolute_to_relative_coordinate_y(const double y);

#define dx(x) ts5_cartesian_to_display_coordinate_x(x)
#define dy(y) ts5_cartesian_to_display_coordinate_y(y)
double ts5_cartesian_to_display_coordinate_x(const double x);
double ts5_cartesian_to_display_coordinate_y(const double y);

#define cx(x) ts5_display_to_cartesian_coordinate_x(x)
#define cy(y) ts5_display_to_cartesian_coordinate_y(y)
double ts5_display_to_cartesian_coordinate_x(const double x);
double ts5_display_to_cartesian_coordinate_y(const double y);

TS5_COLOR ts5_make_rgb_color(const double r, const double g, const double b, 
	const double a);

TS5_COLOR ts5_make_hsl_color(const double h, const double s, const double l, 
	const double a);

TS5_COLOR ts5_make_hsv_color(const double h, const double s, const double v, 
	const double a);

TS5_COLOR ts5_make_named_color(const char *name, const double a);

TS5_COLOR ts5_set_foreground_color(const TS5_COLOR foreground_color);
TS5_COLOR ts5_get_foreground_color();
TS5_COLOR ts5_set_background_color(const TS5_COLOR background_color);
TS5_COLOR ts5_get_background_color();
double ts5_set_drawing_thickness(double drawing_thickness);
double ts5_get_drawing_thickness();
int ts5_set_fill_mode(const int fill_mode);
int ts5_get_fill_mode();
int ts5_set_font_type(const int font_type);
int ts5_get_font_type();
int ts5_set_font_style(const int font_style);
int ts5_get_font_style();
int ts5_set_font_size(int font_size);
int ts5_get_font_size();
int ts5_set_font_index(const int font_index);
int ts5_get_font_index();
int ts5_set_text_alignment(const int text_alignment);
int ts5_get_text_alignment();

#ifdef __cplusplus
}
#endif

